//----------------------------------------------------------------------------
// C main line
//----------------------------------------------------------------------------

#include <m8c.h>        // part specific constants and macros
#include "PSoCAPI.h"    // PSoC API definitions for all User Modules
#include <stdlib.h>
#include <string.h>
#define AD_MAX	8192 
#define AD_CENTER		4086
#define MAX_LCDBAR		16*5

// 20KHz Over Sampling Late 50  20K * 60 * 4 / 20K = 240
#define COUNT8PERIOD	199
#define COUNT8CENTER	99

#define MAX_SUM	8

void Gen_start(double Phase_shift){
	double angle;
	int shift;
	// シフト値を度からカウンター基準に変換する　変換値はshiftに入る
	angle = Phase_shift/360.0;
	shift = (int)(((double)COUNT8PERIOD)*angle);
	// 以下は位相変更。詳細はサイプレスのアプリケーションノートAN2345参照
	// カウンターの停止
	Counter8_2_Stop();
	Counter8_3_Stop();
	// LUT1 (Row0_Output1→GlobalOutEven_1→GlobalInEven_1→Row_0_Input_1) を強制　ＦＡＬＳＥ　にして
	// カウンターのイネーブルをＯＦＦにする
	RDI0LT0 &= 0x0F;
	// Write to first couner period and comp.value
	// 第一相のカウンター終了値とコンペアレジスタをセットする
	Counter8_2_WritePeriod(COUNT8PERIOD);
	Counter8_2_WriteCompareValue(COUNT8CENTER);
	// 第二相のカウンター終了値とコンペアレジスタにシフト値をセットする
	Counter8_3_WritePeriod(shift);
	Counter8_3_WriteCompareValue(shift >> 1);
	// 第一第二ともカウンターをスタートする
	Counter8_2_Start();
	Counter8_3_Start();
	// 第二相カウンター終了値とコンペアレジスタに正規の周期をセットする。
	Counter8_3_WritePeriod(COUNT8PERIOD);
	Counter8_3_WriteCompareValue(COUNT8CENTER);
	// LUT1 (Row_0_Output_1→GlobalOutEven_1→GlobalInEven_1→Row_0_Input_1)を強制　ＴＲＵＥにして
	// カウンターのイネーブルをＯＮにする
	RDI0LT0 |= 0xF0;
}

void main(void)
{
	char str[20];
	int dat;
	int x,y;
	double d;
	int graphPos;
	
	int sumdat[MAX_SUM];
	int i;
	

    // Insert your main routine code here.
	PGA_1_Start(PGA_1_MEDPOWER);
	PGA_2_Start(PGA_2_HIGHPOWER);
	PGA_3_Start(PGA_3_HIGHPOWER);
 	BPF2_1_Start(BPF2_1_HIGHPOWER);
	RefMux_1_Start(RefMux_1_HIGHPOWER);
	//AMD Analog Modulation Control Register 0
	// アナログモジュレーションの接続先設定
	AMD_CR0 &= 0x0F;
	AMD_CR0 |= 2 << 4; //Out Even 0bit
    Counter8_2_Start();
	Counter8_3_Start();
	RDI0LT0 |= 0xF0; // Enable Couners
	LCD_1_Start();
	LCD_1_InitBG(LCD_1_SOLID_BG);

	//検波用位相を設定する
	Gen_start(0);
	ADCINCVR_1_Start(ADCINCVR_1_HIGHPOWER);
	M8C_EnableGInt;
	ADCINCVR_1_GetSamples(0);
	for(i = 0;i<MAX_SUM;i++) sumdat[i]=0; // sum 初期化
	sumdat[1] = 0;
	while(1){
		if(ADCINCVR_1_fIsDataAvailable()){
			dat = ADCINCVR_1_iGetDataClearFlag();
/****移動平均*この間のコメントを外すと移動平均が生きる***********
			for(i = MAX_SUM-2;i >= 0;i--){
				sumdat[i+1] = sumdat[i];
			}
			sumdat[0] = dat;
			dat = 0;
			for(i = 0;i<MAX_SUM;i++){
				dat += sumdat[i];
			}
			dat = dat >> 3; // 1/8
//*****************End　Of　移動平均******/
			LCD_1_Position(1,0);
			LCD_1_PrCString("              ");
			itoa(str,dat,10);
			x = 10-strlen(str);
			LCD_1_Position(1,x);
			LCD_1_PrString(str);
			
			d = ((double)dat + (double)AD_CENTER)/(double)AD_MAX;
			graphPos =(int)((double)MAX_LCDBAR * d);
			LCD_1_DrawBG(0,0,16,graphPos);
		}
		;		
    }    
}
